==> li-pagador-paypal-0.0.1.tar.gz: li-pagador-paypal-0.0.1/src/pagador_paypal/extensao/configuracao.py <==
# -*- coding: utf-8 -*-
import os

from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase, SelecaoBase
from pagador.configuracao.cliente import Script, TipoScript
from pagador_koin import settings


def caminho_do_arquivo_de_template(arquivo):
    diretorio = os.path.dirname(os.path.realpath(__file__))
    return os.path.join(diretorio, "templates", arquivo)


class MeioPagamentoCadastro(CadastroBase):
    logo = Script(tipo=TipoScript.html, nome="logo", conteudo=u'<img src="https://www.paypalobjects.com/webstatic/i/logo/rebrand/ppcom.png" border="0" alt="PayPal" />')

    @property
    def descricao_para_lojista(self):
        script = Script(tipo=TipoScript.html, nome="descricao")
        script.adiciona_linha('<h3>É seguro. É fácil. É PayPal</h3>')
        script.adiciona_linha('<p>São mais de 140 milhões de clientes no mundo todo comprando com segurança e facilidade.</p>')
        script.adiciona_linha('<p>Saiba mais <a href="https://www.paypal.com/br/webapps/mpp/accept-payments-online" target="_blank">aqui</a></p>')
        return script

    @property
    def registro(self):
        script = Script(tipo=TipoScript.html, nome="registro")
        script.adiciona_linha(u'Ainda não tem conta no PayPal?')
        script.adiciona_linha('<a href="https://www.paypal.com/br/cgi-bin/webscr?cmd=_registration-run-validated&country=BR&cid=MCSG5F2W3J6G6LVW" title="Criar conta no PayPal" class="btn btn-info btn-xs" target="_blank">cadastre-se</a>')
        return script

    def to_dict(self):
        return {
            "html": [
                self.descricao_para_lojista.to_dict(),
                self.registro.to_dict()
            ]
        }


PARCELAS = [(0, "Todas"), (1, 1), (2, 2), (3, 3), (4, 4), (5, 5), (6, 6), (7, 7), (8, 8), (9, 9), (10, 10), (11, 11), (12, 12)]


class Formulario(FormularioBase):
    usuario = CampoFormulario("usuario", u"Seu usuário PayPal", requerido=True, tamanho_max=128, ordem=1)
    mostrar_parcelamento = CampoFormulario("mostrar_parcelamento", "Marque para mostrar o parcelamento na listagem dos produtos e na página do produto.", tipo=TipoDeCampo.boleano, requerido=False, ordem=2)
    parcelas_sem_juros = CampoFormulario("parcelas_sem_juros", "Parcelas sem juros", tipo=TipoDeCampo.escolha, requerido=False, ordem=4, texto_ajuda=u"Número de parcelas sem juros para esta forma de pagamento.", opcoes=PARCELAS)


class MeioPagamentoEnvio(object):
    @property
    def css(self):
        return Script(tipo=TipoScript.css, caminho_arquivo=caminho_do_arquivo_de_template("style.css"))

    @property
    def function_enviar(self):
        return Script(tipo=TipoScript.javascript, eh_template=True, caminho_arquivo=caminho_do_arquivo_de_template("javascript.js"))

    @property
    def mensagens(self):
        return Script(tipo=TipoScript.html, caminho_arquivo=caminho_do_arquivo_de_template("mensagens.html"))

    def to_dict(self):
        return [
            self.css.to_dict(),
            self.function_enviar.to_dict(),
            self.mensagens.to_dict()
        ]


class MeioPagamentoSelecao(SelecaoBase):
    logo = Script(tipo=TipoScript.html, nome="logo", conteudo=u'<img src="{{ STATIC_URL }}novo-template/img/bandeiras/paypal.png" alt="Pague com PayPal" title="Pague com PayPal" />', eh_template=True)

    @property
    def bandeiras(self):
        bandeiras = Script(tipo=TipoScript.html, nome="explicativo")
        bandeiras.adiciona_linha('<ul class="bandeiras-pagamento">')
        bandeiras.adiciona_linha('    <li><i class="icone-pagamento visa" title="Visa"></i></li>')
        bandeiras.adiciona_linha('    <li><i class="icone-pagamento mastercard" title="Mastercard"></i></li>')
        bandeiras.adiciona_linha('</ul>')
        return bandeiras

    def to_dict(self):
        return [
            self.logo.to_dict(),
            self.bandeiras.to_dict()
        ]

==> li-pagador-paypal-0.0.2.tar.gz: li-pagador-paypal-0.0.2/src/pagador_paypal/extensao/configuracao.py <==
# -*- coding: utf-8 -*-
import os

from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase, SelecaoBase
from pagador.configuracao.cliente import Script, TipoScript
from pagador_koin import settings


def caminho_do_arquivo_de_template(arquivo):
    diretorio = os.path.dirname(os.path.realpath(__file__))
    return os.path.join(diretorio, "templates", arquivo)


class MeioPagamentoCadastro(CadastroBase):
    logo = Script(tipo=TipoScript.html, nome="logo", conteudo=u'<img src="https://www.paypalobjects.com/webstatic/i/logo/rebrand/ppcom.png" border="0" alt="PayPal" />')

    @property
    def descricao_para_lojista(self):
        script = Script(tipo=TipoScript.html, nome="descricao")
        script.adiciona_linha('<h3>É seguro. É fácil. É PayPal</h3>')
        script.adiciona_linha('<p>São mais de 140 milhões de clientes no mundo todo comprando com segurança e facilidade.</p>')
        script.adiciona_linha('<p>Saiba mais <a href="https://www.paypal.com/br/webapps/mpp/accept-payments-online" target="_blank">aqui</a></p>')
        return script

    @property
    def registro(self):
        script = Script(tipo=TipoScript.html, nome="registro")
        script.adiciona_linha(u'Ainda não tem conta no PayPal?')
        script.adiciona_linha('<a href="https://www.paypal.com/br/cgi-bin/webscr?cmd=_registration-run-validated&country=BR&cid=MCSG5F2W3J6G6LVW" title="Criar conta no PayPal" class="btn btn-info btn-xs" target="_blank">cadastre-se</a>')
        return script

    def to_dict(self):
        return {
            "html": [
                self.descricao_para_lojista.to_dict(),
                self.registro.to_dict()
            ]
        }


PARCELAS = [(0, "Todas"), (1, 1), (2, 2), (3, 3), (4, 4), (5, 5), (6, 6), (7, 7), (8, 8), (9, 9), (10, 10), (11, 11), (12, 12)]


class Formulario(FormularioBase):
    usuario = CampoFormulario("usuario", u"Seu usuário PayPal", requerido=True, tamanho_max=128, ordem=1)
    mostrar_parcelamento = CampoFormulario("mostrar_parcelamento", "Marque para mostrar o parcelamento na listagem dos produtos e na página do produto.", tipo=TipoDeCampo.boleano, requerido=False, ordem=2)
    parcelas_sem_juros = CampoFormulario("parcelas_sem_juros", "Parcelas sem juros", tipo=TipoDeCampo.escolha, requerido=False, ordem=4, texto_ajuda=u"Número de parcelas sem juros para esta forma de pagamento.", opcoes=PARCELAS)


class MeioPagamentoEnvio(object):
    @property
    def css(self):
        return Script(tipo=TipoScript.css, caminho_arquivo=caminho_do_arquivo_de_template("style.css"))

    @property
    def function_enviar(self):
        return Script(tipo=TipoScript.javascript, eh_template=True, caminho_arquivo=caminho_do_arquivo_de_template("javascript.js"))

    @property
    def mensagens(self):
        return Script(tipo=TipoScript.html, caminho_arquivo=caminho_do_arquivo_de_template("mensagens.html"))

    def to_dict(self):
        return [
            self.css.to_dict(),
            self.function_enviar.to_dict(),
            self.mensagens.to_dict()
        ]


class MeioPagamentoSelecao(SelecaoBase):
    selecao = Script(tipo=TipoScript.html, nome="selecao", caminho_arquivo=caminho_do_arquivo_de_template("selecao.html"), eh_template=True)

    def to_dict(self):
        return [
            self.selecao.to_dict()
        ]
